︠fa6c797d-5e68-4af8-90c4-7601f3c31b2ci︠
%md
# Differentiability

So far we have looked at derivatives outside of the notion of differentiability. The problem with this approach, though, is that some functions have one or many points or intervals where their derivatives are undefined. A function $f$ is **differentiable** at a point $c$ if

$\underset{h\to0}{\rm{lim}}\dfrac{f(c+h)-f(c)}{h}$ exists.

Similarly, $f$ is differentiable on an open interval $(a, b)$ if

$\underset{h\to0}{\rm{lim}}\dfrac{f(c+h)-f(c)}{h}$ exists for every $c$ in $(a, b)$.

Basically, $f$ is differentiable at $c$ if $f'(c)$ is defined, by the above definition. Another point of note is that if $f$ is differentiable at $c$, then $f$ is continuous at $c$.

Let's go through a few examples and discuss their differentiability. First, consider the following function:

$f(x)=\dfrac{1}{x^2}$
︡7136db52-c697-4171-85ad-0b1f7959e567︡︡{"done":true,"md":"# Differentiability\n\nSo far we have looked at derivatives outside of the notion of differentiability. The problem with this approach, though, is that some functions have one or many points or intervals where their derivatives are undefined. A function $f$ is **differentiable** at a point $c$ if \n\n$\\underset{h\\to0}{\\rm{lim}}\\dfrac{f(c+h)-f(c)}{h}$ exists.\n\nSimilarly, $f$ is differentiable on an open interval $(a, b)$ if\n\n$\\underset{h\\to0}{\\rm{lim}}\\dfrac{f(c+h)-f(c)}{h}$ exists for every $c$ in $(a, b)$.\n\nBasically, $f$ is differentiable at $c$ if $f'(c)$ is defined, by the above definition. Another point of note is that if $f$ is differentiable at $c$, then $f$ is continuous at $c$.\n\nLet's go through a few examples and discuss their differentiability. First, consider the following function:\n\n$f(x)=\\dfrac{1}{x^2}$"}
︠113ec060-d828-4a78-9880-af9e69f02910︠
plot(1/x^2, x, -5, 5).show(ymin=0, ymax=10)
︡710b4256-18b7-4316-b98f-673fc0f46981︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"14951ce3-2746-4758-b2f5-5253cb26c494","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/16482/tmp_1XyZ0J.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠52a23fcd-1619-4f09-9b96-2bcd31c3d256i︠
%md
To find the limit of the function's slope when the change in x is 0, we can either use the true definition of the derivative and do
︡c5d31ba9-ba4a-4023-9039-a9f1591a9dce︡︡{"done":true,"md":"To find the limit of the function's slope when the change in x is 0, we can either use the true definition of the derivative and do"}
︠d8654a13-f299-47bd-ab82-dd941f02c928o︠
def f(x):
    return 1/x^2

var('h')
((f(x+h)-f(x))/h).rational_simplify().subs(h=0)
︡a9d22620-892e-4c13-b843-d500e6de09b3︡︡{"stdout":"h\n","done":false}︡{"stdout":"-2/x^3","done":false}︡{"stdout":"\n","done":false}︡{"done":true}
︠78db576b-155c-4074-a1a6-3e07810318e8i︠
%md
or we can simply use the rules of differentiation by calling 'derivative(1/x^2, x)'. In any case, we find that

$f'(x)=-\dfrac{2}{x^3}$

Since $f'(x)$ is undefined when $x = 0 (-2/0^2 = ?)$, we say that $f(x)$ is not differentiable at $x = 0$. Since $f'(x)$ is defined for every other $x$, we can say that $f'(x)$ is continuous on $(-\infty, 0) \cup (0, \infty)$, where "$\cup$" denotes the union of two intervals.

How about a function that is everywhere continuous but is not everywhere differentiable? This occurs quite often with piecewise functions, since even though two intervals might be connected, the slope can change radically at their junction. Take a look at the function $g(x) = |x|$.
︡1095e78c-fe79-4831-9738-39aa4db5ea57︡︡{"done":true,"md":"or we can simply use the rules of differentiation by calling 'derivative(1/x^2, x)'. In any case, we find that\n\n$f'(x)=-\\dfrac{2}{x^3}$\n\nSince $f'(x)$ is undefined when $x = 0 (-2/0^2 = ?)$, we say that $f(x)$ is not differentiable at $x = 0$. Since $f'(x)$ is defined for every other $x$, we can say that $f'(x)$ is continuous on $(-\\infty, 0) \\cup (0, \\infty)$, where \"$\\cup$\" denotes the union of two intervals.\n\nHow about a function that is everywhere continuous but is not everywhere differentiable? This occurs quite often with piecewise functions, since even though two intervals might be connected, the slope can change radically at their junction. Take a look at the function $g(x) = |x|$."}
︠12f7ddfe-9b80-4702-8cd8-70a9c0f9d05a︠
plot(abs(x), x, -5, 5)
︡4b3033e5-32b9-4b0b-b0d7-c8421b0982d8︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"0a84a39c-12e3-4148-a17e-50070f51cb68","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/16482/tmp_W1FVcs.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠82769653-c298-4a22-9fed-406b45720cfei︠
%md
Using our knowledge of what "absolute value" means, we can rewrite $g(x)$ in the expanded form

$g(x)=  \begin{cases}
      -x, & x < 0 \\
       0, & x = 0 \\
       x, & x > 0
   \end{cases}
$

This should be easy to differentiate now; we get

$g'(x) = \begin{cases}
        -1, & x < 0 \\
        1, & x > 0
        \end{cases}
$


What about at $x = 0$? The "logical" response would be to see that $g(0) = 0$ and say that $g'(0)$ must therefore equal $0$. Careful, though...looking back at the limit definition of the derivative, the derivative of $f$ at a point $c$ is the limit of the slope of $f$ as the change in its independent variable approaches $0$. Really, the only relevant piece of information is the behavior of function's slope *close* to $c$. Referring back to the example, since the limit of $g'(x)$ as $x$ approaches $0$ from the left $\neq$ the limit of $g'(x)$ as $x$ approaches $0$ from the right, $g'(0)$ does not exist. We can use the limit definition of the derivative to prove this:

$g'(x)=\underset{h \to 0}{\rm{lim}}\dfrac{|x + h| - |x|}{h} =\underset{h \to 0}{\rm{lim}}\dfrac{|x + h| - |x|}{h}*\dfrac{|x + h| + |x|}{|x + h| + |x|} = \underset{h\to0}{\rm{lim}}\dfrac{x^2+2xh+h^2-x^2}{h(|x+h|+|x|)}=\underset{h\to0}{\rm{lim}}\dfrac{2x}{(|x+h|+|x|)}=\dfrac{2x}{|2x|}=\dfrac{x}{|x|}$, so $g'(0)=\dfrac{0}{|0|}$, which is undefined

 In this form, it makes far more sense why $g'(0)$ is undefined. By simply looking at the graph of $g$, too, one can see that the sudden "twist" at $x = 0$ is responsible for our inability to evaluate $g'$ there. We can now justly pronounce that $g$ is differentiable on $(-\infty, 0) \cup (0, \infty)$, so $g'$ is continuous on that same interval.

The third function of discussion has a couple of quirks--take a look.
︡84ff756f-89b7-4792-8723-4a6e2d3a8f69︡
︠4df4f35b-91d8-46ec-a051-1b08880b95c1i︠
p = plot(sqrt(x-2), x, 2, 5)
pt1 = point((3, 1), rgbcolor="white", pointsize=30, faceted=True)
pt2 = point((3, 2), rgbcolor="black", pointsize=30)
l = line([(3, 1), (3, 2)], linestyle="--")
(p+pt1+pt2+l).show(xmin=0)
︡3fdc55e3-104f-401e-b35e-91f91d0c8de8︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"687c6451-b393-467c-9c7f-a29ba8010d0b","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/16482/tmp_nidNJF.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠d1444f9a-0afc-45d4-9f6e-440931e974bei︠
%md
Not only is $v(t)$ defined solely on $[2, ∞)$, it has a jump discontinuity at $t = 3$. The jump discontinuity causes $v'(t)$ to be undefined at $t = 3$; do you see why? Using a slightly modified limit definition of the derivative, think of what

$\underset{x\to{c}}{\rm{lim}}\dfrac{f(x)-f(c)}{x-c}$

would be for $c = 3$ and some $x$ very close to $3$. The resulting slope would be astronomically large either negatively or positively, right? In fact, the dashed line connecting $v(t)$ for $t \neq 3$ and $v(3)$ is what the tangent line will look like at that point. Since a function's derivative cannot be infinitely large and still be considered to "exist" at that point, $v$ is not differentiable at $t=3$.
︡a971235b-029b-4889-97a0-17b08f1bb243︡︡{"done":true,"md":"Not only is $v(t)$ defined solely on $[2, ∞)$, it has a jump discontinuity at $t = 3$. The jump discontinuity causes $v'(t)$ to be undefined at $t = 3$; do you see why? Using a slightly modified limit definition of the derivative, think of what\n\n$\\underset{x\\to{c}}{\\rm{lim}}\\dfrac{f(x)-f(c)}{x-c}$\n\nwould be for $c = 3$ and some $x$ very close to $3$. The resulting slope would be astronomically large either negatively or positively, right? In fact, the dashed line connecting $v(t)$ for $t \\neq 3$ and $v(3)$ is what the tangent line will look like at that point. Since a function's derivative cannot be infinitely large and still be considered to \"exist\" at that point, $v$ is not differentiable at $t=3$."}
︠751d69ba-f7dc-4f5c-980a-45f43669b875i︠
%md
# The Mean Value Theorem
 The Mean Value Theorem is very important for the discussion of derivatives; even though it might seem somewhat obvious, it is actually very important to many other concepts in calculus. We'll start with an example.

Consider the vast, seemingly endless state of Montana. Now, pretend that you are driving across Montana so that you can get to Washington, and you want to do so as quickly as possible. The problem, however, is that the signs posted every few miles explicitly state that the speed limit is 70 miles per hour. "Oh well," you tell yourself. "When I'm on the open road, I will go as fast as I want. When I approach a town, though, I will slow down so that the police are none the wiser."

Since you had been staying with some relatives in the town of Springdale, you first head east at the brisk pace of 90 miles per hour until, feeling your stomach rumble (you really aren't cut out for these long drives), you stop in Livingston for some lunch. When you arrive, however, a policeman signals you to pull over! "What did I do wrong?" you sweetly ask the officer. Giving you a hard look, the policeman responds, "Though I didn't actually see you speeding at any point on your way here, I know that you must have, since one of my buddies back in Livingston tells me that you left there only 10 minutes ago, and our two towns are about 15 miles apart. I won't cite you for it this time, but you'd better drive slower in the future."

The question is: How did the policeman know you had been speeding? Well, since it took you 10 minutes to travel 15 miles, your average speed was 90 miles per hour. So either you traveled at exactly 90 miles per hour the entire time, or you traveled at more than 90 part of the way and less than ninety part of the way. In either case, you were going faster than the speed limit at some point in time.

The **Mean Value Theorem** has a very similar message: if a function $f$ is continuous on the closed interval $[a, b]$ and is differentiable on the open interval $(a, b)$, then there is some $c$ in $(a, b)$ such that

$f'(c)=\dfrac{f(b)-f(a)}{b-a}$

Basically, the average slope of $f$ between $a$ and $b$ will equal the actual slope of $f$ at some point between $a$ and $b$. To illustrate the Mean Value Theorem, consider the function $f(x) = x*\sin(x)$ for $x$ in $[0, \dfrac{9\pi}{2}]$. Assume that $f$ is differentiable on $(0, \dfrac{9\pi}{2})$ (it is) and continuous on $[0, \dfrac{9\pi}{2}]$ (it is). By the Mean Value Theorem, there is at least one $c$ in $(0, \dfrac{9\pi}{2})$ such that

$f'(c)=\dfrac{f(\dfrac{9\pi}{2})-f(0)}{\dfrac{9\pi}{2}-0}=\dfrac{\dfrac{9\pi}{2}*\sin(\dfrac{9\pi}{2})-0*\sin(0)}{\dfrac{9\pi}{2}-0}=\sin(\dfrac{9\pi}{2})=1$

 And such a $c$ does exist, in fact. You can use SageMath's solve function to verify this:
︡6cb16644-7c97-4135-83dd-2d94f35020d1︡︡{"done":true,"md":"# The Mean Value Theorem\n The Mean Value Theorem is very important for the discussion of derivatives; even though it might seem somewhat obvious, it is actually very important to many other concepts in calculus. We'll start with an example.\n\nConsider the vast, seemingly endless state of Montana. Now, pretend that you are driving across Montana so that you can get to Washington, and you want to do so as quickly as possible. The problem, however, is that the signs posted every few miles explicitly state that the speed limit is 70 miles per hour. \"Oh well,\" you tell yourself. \"When I'm on the open road, I will go as fast as I want. When I approach a town, though, I will slow down so that the police are none the wiser.\"\n\nSince you had been staying with some relatives in the town of Springdale, you first head east at the brisk pace of 90 miles per hour until, feeling your stomach rumble (you really aren't cut out for these long drives), you stop in Livingston for some lunch. When you arrive, however, a policeman signals you to pull over! \"What did I do wrong?\" you sweetly ask the officer. Giving you a hard look, the policeman responds, \"Though I didn't actually see you speeding at any point on your way here, I know that you must have, since one of my buddies back in Livingston tells me that you left there only 10 minutes ago, and our two towns are about 15 miles apart. I won't cite you for it this time, but you'd better drive slower in the future.\"\n\nThe question is: How did the policeman know you had been speeding? Well, since it took you 10 minutes to travel 15 miles, your average speed was 90 miles per hour. So either you traveled at exactly 90 miles per hour the entire time, or you traveled at more than 90 part of the way and less than ninety part of the way. In either case, you were going faster than the speed limit at some point in time.\n\nThe **Mean Value Theorem** has a very similar message: if a function $f$ is continuous on the closed interval $[a, b]$ and is differentiable on the open interval $(a, b)$, then there is some $c$ in $(a, b)$ such that\n\n$f'(c)=\\dfrac{f(b)-f(a)}{b-a}$\n\nBasically, the average slope of $f$ between $a$ and $b$ will equal the actual slope of $f$ at some point between $a$ and $b$. To illustrate the Mean Value Theorem, consider the function $f(x) = x*\\sin(x)$ for $x$ in $[0, \\dfrac{9\\pi}{2}]$. Assume that $f$ is differentiable on $(0, \\dfrac{9\\pi}{2})$ (it is) and continuous on $[0, \\dfrac{9\\pi}{2}]$ (it is). By the Mean Value Theorem, there is at least one $c$ in $(0, \\dfrac{9\\pi}{2})$ such that\n\n$f'(c)=\\dfrac{f(\\dfrac{9\\pi}{2})-f(0)}{\\dfrac{9\\pi}{2}-0}=\\dfrac{\\dfrac{9\\pi}{2}*\\sin(\\dfrac{9\\pi}{2})-0*\\sin(0)}{\\dfrac{9\\pi}{2}-0}=\\sin(\\dfrac{9\\pi}{2})=1$\n\n And such a $c$ does exist, in fact. You can use SageMath's solve function to verify this:"}
︠4655e404-87fa-4476-b134-c83e20cb2bcc︠
solve(derivative(x*sin(x), x) == 0, x)
︡2e2c36b9-0228-498b-b242-4c92d42fb305︡︡{"stdout":"[x == -sin(x)/cos(x)]\n","done":false}︡{"done":true}
︠8c6d933a-5ef4-4ac7-8e70-df3e532098e6i︠
%md
From the code's output, you can see that this is true whenever $-\sin(x)/\cos(x)$ is 0. Thus $c = 0$, $\pi$, $2\pi$, $3\pi$, and $4\pi$, so the Mean Value Theorem is satisfied for $f$ on the interval $[0, \dfrac{9\pi}{2}]$.
︡35ed6fb2-a013-448c-9fbd-6c5ddaf82ffe︡︡{"done":true,"md":"From the code's output, you can see that this is true whenever $-\\sin(x)/\\cos(x)$ is 0. Thus $c = 0$, $\\pi$, $2\\pi$, $3\\pi$, and $4\\pi$, so the Mean Value Theorem is satisfied for $f$ on the interval $[0, \\dfrac{9\\pi}{2}]$."}
︠f0cb0eb4-c8cc-49a9-8eb4-47399dd67cebi︠
%md
## Rolle's Theorem
**Rolle's Theorem** states that if a function $g$ is differentiable on $(a, b)$, continuous $[a, b]$, and $g(a) = g(b)$, then there is at least one number $c$ in $(a, b)$ such that $g'(c) = 0$. To see this, consider the everywhere differentiable and everywhere continuous function $g(x) = (x-3)*(x+2)*(x^2+4)$. To prove that $g'$ has at least one zero for $x$ in $(-\infty, \infty)$, notice that $g(3) = g(-2) = 0$. By Rolle's Theorem, there must be at least one $c$ in $(-2, 3)$ such that $g'(c) = 0$.

## Practice Problems
 Determine the interval(s) on which the following functions are continuous and the interval(s) on which they are differentiable.

 1) $f(x)=\sqrt[3]{x-3}+3$
︡82697801-b849-41de-985c-6b9b978ed1cb︡︡{"done":true,"md":"## Rolle's Theorem\n**Rolle's Theorem** states that if a function $g$ is differentiable on $(a, b)$, continuous $[a, b]$, and $g(a) = g(b)$, then there is at least one number $c$ in $(a, b)$ such that $g'(c) = 0$. To see this, consider the everywhere differentiable and everywhere continuous function $g(x) = (x-3)*(x+2)*(x^2+4)$. To prove that $g'$ has at least one zero for $x$ in $(-\\infty, \\infty)$, notice that $g(3) = g(-2) = 0$. By Rolle's Theorem, there must be at least one $c$ in $(-2, 3)$ such that $g'(c) = 0$. \n\n## Practice Problems\n Determine the interval(s) on which the following functions are continuous and the interval(s) on which they are differentiable. \n \n 1) $f(x)=\\sqrt[3]{x-3}+3$"}
︠21371c81-55c0-4a90-8622-ed72298d6da6︠
# Taking the cube root (or any odd root) of a negative number does not work well in Python, so one has to use multiple plot commands for functions such as x^(1/3) to compensate for the intervals on which x is negative
plot((x-3)^(1/3)+3, x, 3, 6) + plot(-(-x+3)^(1/3)+3, x, 0, 3)
︡d6d2b1e4-2257-414f-870f-c4c80f55405e︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"583eebc1-74f4-4c62-bd38-e70171f9c220","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/16482/tmp_6i03e7.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠88078235-6718-4108-abba-133751589bb0︠
%md
2) $f(x)=  \begin{cases}
      \sin x & 0\leq x\leq \dfrac{\pi}{2} \\
      \cos 2x + 2 & \dfrac{\pi}{2} \leq x \leq \pi
   \end{cases}
$

Hint: Do both pieces of $f(x)$ match at $\dfrac{\pi}{2}$? Do the derivatives of the two pieces match there?
︡b9147a10-cc68-4b18-a475-769324d01dfa︡︡{"done":true,"md":"2) $f(x)=  \\begin{cases} \n      \\sin x & 0\\leq x\\leq \\dfrac{\\pi}{2} \\\\\n      \\cos 2x + 2 & \\dfrac{\\pi}{2} \\leq x \\leq \\pi\n   \\end{cases}\n$\n\nHint: Do both pieces of $f(x)$ match at $\\dfrac{\\pi}{2}$? Do the derivatives of the two pieces match there?"}
︠f30dce93-b6ca-4667-99a7-2aa57c7db547︠
plot(sin(x), x, 0, pi/2)+plot(cos(2*x)+2, x, pi/2, pi)
︡fa03ee42-101c-4586-ba4c-9f61e43e636c︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"97dae1f9-2227-4baf-bf46-e82729858857","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/16482/tmp_cBfNqI.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠6363cda6-f967-4cd4-950e-3d437e1a30b2i︠
%md
3) $h(x) =\ln x + 2$, $ x=1$
︡fa077193-382c-4d76-af98-68c3bc4b7401︡︡{"done":true,"md":"3) $h(x) =\\ln x + 2$, $ x=1$"}
︠cf006c65-c395-4f23-b81d-d48b9cf9c90a︠
point((1, ln(1)+2), rgbcolor='black').show()
︡c2084ccf-d7cd-4a40-acb3-d94268923208︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"2e7b8faf-498f-484d-9f05-26e21bd18705","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/16482/tmp_9GXyle.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠12421f99-5da0-4d9a-a492-1a9f6d810f2bi︠
%md
Use the Mean Value Theorem to answer the following questions.

4) Marvin claims that he is a speed-walker and that he always walks at 6 miles per hour. He tells you that it took him only 12 minutes to walk one mile this morning. Prove that Marvin was not actually speed-walking at some point during his walk.

5) Jessica plays for a recreational basketball team, and has noticed an interesting trend: the number of points she scores each game has increased linearly for the first five games of the season. If she scored 10 points in the first game, must there be some game of the last five in which she scored 14 points?

6) Suppose that $f'(x) < 1$ for $x$ in $(0, 4)$. If $f(0) = 1$, can $f(4) = 5$?
︡dbbbd3f9-a0ca-4146-8098-1d4da5cddbff︡︡{"done":true,"md":"Use the Mean Value Theorem to answer the following questions.\n\n4) Marvin claims that he is a speed-walker and that he always walks at 6 miles per hour. He tells you that it took him only 12 minutes to walk one mile this morning. Prove that Marvin was not actually speed-walking at some point during his walk.\n\n5) Jessica plays for a recreational basketball team, and has noticed an interesting trend: the number of points she scores each game has increased linearly for the first five games of the season. If she scored 10 points in the first game, must there be some game of the last five in which she scored 14 points? \n\n6) Suppose that $f'(x) < 1$ for $x$ in $(0, 4)$. If $f(0) = 1$, can $f(4) = 5$?"}
︠37cbe134-6a58-437f-ac95-016763c264bfi︠
%md
<h4>To view answers, select this cell and paste it into your own sagews, and then double click on it</h4>
<!--
    1) f is continuous on (-∞, ∞) and is differentiable on (-∞, 3) U (3, ∞).
    2) f is continuous on [0, π] and is differentiable on (0, π/2) U (π/2, π).
    3) h is neither continuous nor differentiable at 1, since both require that an open interval about the point in question be defined.
    4) By the Mean Value Theorem, there was some point during Marvin's walk at which he was moving (1 - 0)/(12/60 - 0) = 5 miles per hour, so he did not actually speed-walk the entire time.
    5) To apply the Mean Value Theorem to a function, the function must be both continuous and differentiable on an interval. The function that models Jessica's points per game (its exact definition is unknown) does not necessarily include the number 14, since it could increase at a rate of 3 points per game, 5 points per game, etc. and therefore not pass through 14.
    6) By the Mean Value Theorem, there exists a c in (0, 4) such that (f(4)-f(0))/(4-0) = f'(c). Thus f(4)-f(0) = f'(c)*4, 5-1 = f'(c)*4, and 0 = f'(c). Since f'(c) is necessarily less than 1, the statement does not hold and therefore f(4) cannot equal 5.
     -->
︡972c5d20-93d0-46a7-bc81-39c0201482da︡︡{"done":true,"md":"<h4>To view answers, select this cell and paste it into your own sagews, and then double click on it</h4>\n<!--\n    1) f is continuous on (-∞, ∞) and is differentiable on (-∞, 3) U (3, ∞).\n    2) f is continuous on [0, π] and is differentiable on (0, π/2) U (π/2, π).\n    3) h is neither continuous nor differentiable at 1, since both require that an open interval about the point in question be defined.\n    4) By the Mean Value Theorem, there was some point during Marvin's walk at which he was moving (1 - 0)/(12/60 - 0) = 5 miles per hour, so he did not actually speed-walk the entire time.\n    5) To apply the Mean Value Theorem to a function, the function must be both continuous and differentiable on an interval. The function that models Jessica's points per game (its exact definition is unknown) does not necessarily include the number 14, since it could increase at a rate of 3 points per game, 5 points per game, etc. and therefore not pass through 14.\n    6) By the Mean Value Theorem, there exists a c in (0, 4) such that (f(4)-f(0))/(4-0) = f'(c). Thus f(4)-f(0) = f'(c)*4, 5-1 = f'(c)*4, and 0 = f'(c). Since f'(c) is necessarily less than 1, the statement does not hold and therefore f(4) cannot equal 5.\n     -->"}
︠ed4d2966-7d5c-4965-b8e5-6f854bdb81c1i︠
%md
<center>[Previous: The Definition of the Derivative](The_Definition_of_the_Derivative.sagews) | [To Main](Introduction.sagews) | [Next: The Rules of Differentiation](The_Rules_of_Differentiation.sagews)</center>
︡166a2a4b-b80a-42c9-8939-407c03baf2c1︡{"done":true,"md":"<center>[Previous: The Definition of the Derivative](The_Definition_of_the_Derivative.sagews) | [To Main](Introduction.sagews) | [Next: The Rules of Differentiation](The_Rules_of_Differentiation.sagews)</center>"}
︠6b03d475-5b98-428b-9e74-ea3a577051cc︠









